diff --git a/iTrust/WebRoot/WEB-INF/web.xml b/iTrust/WebRoot/WEB-INF/web.xml
index 85aff0ab1c637402e0409a0140cb726a5754dc5e..aa258d6cab4e7c258a1c7429be34407b3ad79c4a 100644
--- a/iTrust/WebRoot/WEB-INF/web.xml
+++ b/iTrust/WebRoot/WEB-INF/web.xml
@@ -84,7 +84,11 @@
 	</security-role>
 	<security-role>
 		<role-name>tester</role-name>
-	</security-role>		
+	</security-role>
+	
+	<security-role>
+		<role-name>preRegisteredPatient</role-name>
+	</security-role>	
 
 
 	<!-- Define all role-based authorization folders
@@ -95,6 +99,7 @@
 		/auth/admin/*         - JSPs for Administrators only
 		/auth/staff/*         - JSPs for only hospital staff (hcps, uaps, admin, lt)
 		/auth/patient/*       - JSPs for patients only
+		/auth/preRegisteredPatient/*       - JSPs for preRegisteredPatients only
 		/auth/lt/*       	  - JSPs for LTs only
 		
 		If any user attempts to access a folder that their role is not authorized for, 
@@ -126,6 +131,9 @@
 			<role-name>tester</role-name>
 			<role-name>pha</role-name>
 			<role-name>lt</role-name>
+			
+			<role-name>preRegisteredPatient</role-name>
+			
 		</auth-constraint>
 	</security-constraint>
 
@@ -278,6 +286,23 @@
 		</auth-constraint>
 	</security-constraint>
 	
+	
+	<security-constraint>
+		<display-name>PreRegisteredPatient Only</display-name>
+		<web-resource-collection>
+			<web-resource-name>
+				Only PreRegisteredPatient are Allowed
+			</web-resource-name>
+			<!-- Define the context-relative URL(s) to be protected -->
+			<url-pattern>/auth/preRegisteredPatient/*</url-pattern>
+		</web-resource-collection>
+		<auth-constraint>
+			<!-- Anyone with one of the listed roles may access this area -->
+			<role-name>preRegisteredPatient</role-name>
+		</auth-constraint>
+	</security-constraint>
+	
+	
 	<security-constraint>
 		<display-name>PHA Only</display-name>
 		<web-resource-collection>
diff --git a/iTrust/src/edu/ncsu/csc/itrust/enums/Role.java b/iTrust/src/edu/ncsu/csc/itrust/enums/Role.java
index 7449b84ac51590834bf992d93efce89a0868a4af..4e22329ffd81d838743918f18a79ba59303e772e 100644
--- a/iTrust/src/edu/ncsu/csc/itrust/enums/Role.java
+++ b/iTrust/src/edu/ncsu/csc/itrust/enums/Role.java
@@ -1,10 +1,12 @@
 package edu.ncsu.csc.itrust.enums;
 
 /**
  * The iTrust user roles: Patient, ER, HCP, UAP, LT, PHA, Administrator and Tester.
  * Consult the requirements for the contextual meanings of these individual choices.
  */
 public enum Role {
+	/**PRE-REGISTERED PATIENT*/
+	PREREGISTEREDPATIENT("preRegisteredPatient", "Patients", 0L), 
 	/**PATIENT*/
 	PATIENT("patient", "Patients", 0L), 
 	/**ER*/
@@ -1,10 +1,12 @@
 
 /**
- * The iTrust user roles: Patient, ER, HCP, UAP, LT, PHA, Administrator and Tester.
+ * The iTrust user roles: Pre-registered Patient, Patient, ER, HCP, UAP, LT, PHA, Administrator and Tester.
  * Consult the requirements for the contextual meanings of these individual choices.
  */